'''VERY UNCLEAN AND MESSY CODE WHICH MAKES  A DARKMODE GUI VERSION OF AN ENCODER WITHOUT ICHOR '''
import extraEncodings.ciphers
from extraEncodings.ciphers import *
try:
    from tkinter import *
except ImportError:
    print('Sorry but GUI is unavailable because you do not have tkinter, the python interface for Tk and Tcl')
    pass
import os
def startGUI():
    root = Tk()
    root.title("Encoding GUI")
    root.configure(bg='black')
    root.maxsize()
    Mainframe = Frame(root)   
    Mainframe.grid(column=0,row=0,sticky=(N,W,E,S))
    Mainframe.configure(bg='black')
    root.columnconfigure(0,weight=1)
    root.rowconfigure(0, weight=1)
    encodablevar = StringVar()
    encoded_string = StringVar()
    wew = IntVar()
    entry = Entry(Mainframe,width=12,textvariable=encodablevar,bg='black',fg='dark cyan')
    entry.grid(column=3,row=1,sticky=(N,W))
    entry.focus()
    def GEN2codeGUI():
     ''' Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text   editor rendering it incorrectly'''
     encoded_string.set('')
     entryvalue = entry.get()
     Character_to_decode = str(entryvalue)
     for character in Character_to_decode:
         charpos = Gen2.index(character)
         ResultStr = str(Gen2[-charpos])
         encoded_string.set(str(encoded_string.get()) + ResultStr)
    def GTX2CodeGUI():
        entryvalue = entry.get()
        '''Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text editor rendering it incorrectly'''
        #make sure this is always a string
        encoded_string.set('')
        Character_to_decode = str(entryvalue)
        for character in Character_to_decode:
            charpos = GTX2.index(character)
            ResultStr = str(GTX2[-charpos - 1])
            encoded_string.set(str(encoded_string.get()) + ResultStr)
    def LTF64CodeGUI(): 
        '''Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text editor rendering it incorrectly'''
        #make sure this is always a string
        encoded_string.set('')
        entryvalue = entry.get()
        Character_to_decode = str(entryvalue)
        for character in Character_to_decode:
            charpos = LTF64.index(character)
            ResultStr = str(LTF64[-charpos -2])
            encoded_string.set(str(encoded_string.get()) + ResultStr)
    def encoderGUI():
        if wew.get() ==0:
            LTF64CodeGUI()
        if wew.get() == 1:
            GTX2CodeGUI()
        if wew.get() == 2:
            GEN2codeGUI()
    def kill():
        os.sys.exit()
    Button(Mainframe,text='Encode',command=encoderGUI,bg='black',fg='dark cyan').grid(column=3,row=4)
    Button(Mainframe,text='Quit All Encoders',command=kill,bg='black',fg='dark cyan') .grid(column=3,row=5)
    Radiobutton(Mainframe,text='LTF64',variable=wew,value=0,bg='black',fg='dark cyan').grid(column=1,row=1,sticky=(N))
    Radiobutton(Mainframe,text='GTX2',variable=wew,value=1,bg='black',fg='dark cyan').grid(column=1,row=2,sticky=(N))
    Radiobutton(Mainframe,text='Gen2',variable=wew,value=2,bg='black',fg='dark cyan').grid(column=1,row=3,sticky=(N))
    Label(Mainframe,text='Encoder',bg='black',fg='dark cyan').grid(column=3,row=0,sticky=(N))
    Label(Mainframe,text='Encoded text:',bg='black',fg='dark cyan').grid(column=3,row=2,sticky=(N))
    Entry(Mainframe,textvariable=encoded_string,bg='black',fg='dark cyan').grid(column=4,row=2)
    for child in Mainframe.winfo_children(): 
        child.grid_configure(padx=5, pady=5)
    root.bind("<Return>", encoderGUI)
    Mainframe.mainloop()
time.sleep(0.4)
print('Initialization:enocdingsGui.py,Complete')
if __name__ == "__main__":
    startGUI()


#imports
import os
import time
import  extraEncodings.ciphers
from  extraEncodings.ciphers import *
import  extraEncodings.encodingsGui
from extraEncodings.encodingsGui import *
print('Initialization:encodings.py,Complete')
#functions to encode and decode
def encodeto():
    entype = input("Which encoding?")
    if entype.upper() == "ichor".upper():
        obj = input("Encode:")
        for character in obj:
            encode = ichor[character]
            if character == obj[-1]:
                print(encode,end="\n")
            else:
                print(encode,end=" ")
    if entype.upper() == "GEN2":
        Gen2Code(input('Encode:'))
    if entype.upper() == 'LTF64':
        LTF64Code(input('Encode:'))
    if entype.upper() == 'GTX2':
        GTX2Code(input('Decode '))
    if entype.upper() == 'LGC':
        LGC.code(input('Encode'))

def decodeto():
    detype = input("Which decoding?")
    if detype.upper() == "ichor".upper():
        obj = input("Decode:")
        objspce = obj.count(" ") + 1
        obj = obj.split(" ")
        for r in range(objspce):
            de = int(obj[r])
            decode = ichor.reverse[de]
            if de == obj[-1]:
                print(decode,end="\n")
            else:
                print(decode,end="")
    if detype.upper() == "GEN2":
        Gen2Code(input('Decode:'))
    if detype.upper() == 'LTF64':
        LTF64Code(input('Decode:'))
    if detype.upper() == 'GTX2':
        GTX2Code(input('Decode '))
    if detype.upper() == 'LGC':
        LGC.code(input('Decode'))
def clear():
    ostype = os.name
    if ostype.upper() == 'posix'.upper():
        os.system('clear')
    if ostype.upper() == 'nt'.upper():
        os.system('cls')




#while true loop for coder
def coder():
    x = ""
    clear()
    while x != "exit".upper():
        x = input("\nEncode, Decode, Clear, Credits, GUI , or exit?:")
        x = x.upper()
        if x == "encode".upper():
            encodeto()
        if x == "decode".upper():
            decodeto()
        if x  == "Credits".upper():
            print("Everything: code80191@gmail.com")
            time.sleep(1)
        if x == "clear".upper():
            clear()
        if x == "GUI".upper():
            startGUI()
        if  x == "secrets".upper():
            print(''':>9~;9cW;5C:/9~;9cCW;5C:/9~;9''')
time.sleep(0.5)
print('Initialization:encodings.py,Complete')
print('Finshed!')
time.sleep(2)
if __name__ == "__main__":
    coder()



import  extraEncodings
import random
import time
countingstuff = 0
#Gen2
Encodeable_letters = r'''aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ1234567890!@\#$%^&*()`~-=_+[]}{'\";:| ,.<>/?'''
class TwoWayDict(dict):
    def __init__(self, my_dict):
        dict.__init__(self, my_dict)
        self.reverse = {v : k for k,v in my_dict.items()}

    def __setitem__(self, key, value):
        dict.__setitem__(self, key, value)
        self.reverse.__setitem__(value, key)

    def pop(self, key):
        self.reverse.pop(self[key])
        dict.pop(self, key)
    def add(self,key,value):
        self.reverse[value] = key
        dict[value] = key
class Encoding():
    '''A way to generate a encoding for your purposes. \n
    Look at CreateAnEncoding.py to see an example of making an instance
    '''
    def __init__(self,rate):
        self.rate = rate
        x = 0
        self.encodingnormal = {}
        for letter in Encodeable_letters:
            x = x + rate
            self.encodingnormal[letter] = str(x)
        self.encoding = TwoWayDict(self.encodingnormal)
    
    def encode(self,obj):
        for character in obj:
            encode = self.encoding[character]
            if character == obj[-1]:
                print(encode,end="\n")
            else:
                print(encode,end=" ")
    
    def decode(self,obj):
        objspce = obj.count(" ") + 1
        obj = obj.split(" ")
        for r in range(objspce):
            de = obj[r]
            decode = self.encoding.reverse[de]
            if de == obj[-1]:
                print(decode,end="\n")
            else:
                print(decode,end="")
    def findrate(self):
        print(f'Rate of {self} is {self.rate}')
        for k,v in self.encoding.reverse.items():
            print(f'{k}:{v}',end='  ')
class ListEncoding():
    def __init__(self,mix):
        self.encoding = []
        self.mix = mix
        for letter in Encodeable_letters:
            self.encoding.append(letter)
    def code(self,Character_to_decode):
        Character_to_decode = str(Character_to_decode)
        for character in Character_to_decode:
            charpos = self.encoding.index(character)
            ResultStr = str(self.encoding[-charpos  -self.mix])
            print(ResultStr,end='')
class RandomEncoding(Encoding):
    '''A way to generate a random encoding for your purposes. \n
    Encoding and decoding works the same as Encoding() \n
    Look at CreateAnEncoding.py and the Encoding() for an example of how to use it.
    '''
    def __init__(self,MaxRandom,MinRandom):
        self.rate = random.randint(MinRandom,MaxRandom)
        x = 0
        self.encodingnormal = {}
        for letter in Encodeable_letters:
            x = x + self.rate
            self.encodingnormal[letter] = str(x)
        self.encoding = TwoWayDict(self.encodingnormal)
Gen2=[]
GTX2 = []   
ichorrev = {
    "a":"1",
    "A":"2",
    "b":"3",
    "B":"4",
    "c":"5",
    "C":"6",
    "d":"7",
    "D":"8",
    "e":"9",
    "E":"10",
    "f":"11",
    "F":"12",
    "g":"13",
    "G":"14",
    "h":"15",
    "H":"16",
    "i":"17",
    "I":"18",
    "j":"19",
    "J":"20",
    "k":"21",
    "K":"22",
    "l":"23",
    "L":"24",
    "m":"25",
    "M":"26",
    "n":"27",
    "N":"28",
    "o":"29",
    "O":"30",
    "p":"31",
    "P":"32",
    "q":"33",
    "Q":"34",
    "r":"35",
    "R":"36",
    "s":"37",
    "S":"38",
    "t":"39",
    "T":"40",
    "u":"41",
    "U":"42",
    "v":"43",
    "V":"44",
    "w":"45",
    "W":"46",
    "x":"47",
    "X":"48",
    "y":"49",
    "Y":"50",
    "z":"51",
    "Z":"52",
    " ":"53",
    ".":"54",
    "?":"55",
    "!":"56",
    ",":"57",
    ";":"58",
    ":":"59",
    "'":"60",
    '"':"61",
    "@":"62",
    "_":"63",
    "-":"64",
    "[":"64",
    "]":"65",
    "{":"66",
    "}":"67",
    "#":"68",
    "$":"69",
    "%":"70",
    "^":"71",
    "&":"72",
    "*":"73",
    "(":"74"
}
LGC = ListEncoding(-1)
ichor = TwoWayDict(ichorrev)
LTF64 = []
for letter in Encodeable_letters:
    countingstuff = countingstuff + 1
    ichor[letter] = countingstuff
    Gen2.append(letter)
    LTF64.append(letter)
    GTX2.append(letter)
def Gen2Code(Character_to_decode):
    ''' Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text   editor rendering it incorrectly'''
    #make sure this is always a string
    Character_to_decode = str(Character_to_decode)
    for character in Character_to_decode:
        charpos = Gen2.index(character)
        ResultStr = str(Gen2[-charpos])
        print(ResultStr,end='')
def LTF64Code(Character_to_decode):
    '''Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text editor rendering it incorrectly'''
    #make sure this is always a string
    Character_to_decode = str(Character_to_decode)
    for character in Character_to_decode:
        charpos = LTF64.index(character)
        ResultStr = str(LTF64[-charpos -2 ])
        print(ResultStr,end='')
def GTX2Code(Character_to_decode):
    '''Only use with r-strings due to % and \. Don't mind strange coloration as that is just your text editor rendering it incorrectly'''
    #make sure this is always a string
    Character_to_decode = str(Character_to_decode)
    for character in Character_to_decode:
        charpos = GTX2.index(character)
        ResultStr = str(GTX2[-charpos  -2])
        print(ResultStr,end='')
#Example below
#LTF64Code(r'Fire balls')
time.sleep(0.3)
print('Initialization:ciphers.py,Complete')


import setuptools
with open("README.md", "r") as README:
    long_description = README.read()

setuptools.setup(
    name="extraEncodings",
    version="1.5.7.2",
    author="codecode",
    author_email="code80191@gmail.com",
    description="Extra text encodings and encoders.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        'Development Status :: 5 - Production/Stable ',
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.8',
)
